==> cscec5b-fbxt-api-3.0.0-20210802.063502-235-sources.jar: com/ejianc/business/fbxt/grap/vo/GrapDetailVO.java <==
package com.ejianc.business.fbxt.grap.vo;

import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;
import com.ejianc.framework.skeleton.template.BaseVO;


/**
 * 进度计量子表实体
 * 
 * @author generator
 * 
 */
public class GrapDetailVO extends BaseVO {
    private static final long serialVersionUID = 1L;
    
    private Long grapId; // 主表主键ID
    private String memo; // 备注
    private String infoId; // 清单主键
    private String infoCode; // 清单编码
    private String infoName; // 清单名称
    private String unit; // 单位
    private java.math.BigDecimal num; // 数量
    private java.math.BigDecimal price; // 无税单价
    private java.math.BigDecimal mny; // 金额
    

    /**
     * 主表主键ID
     */
    public Long getGrapId() {
        return grapId;
    }

    /**
     * 主表主键ID
     */
    public void setGrapId(Long grapId) {
        this.grapId = grapId;
    }
    /**
     * 备注
     */
    public String getMemo() {
        return memo;
    }

    /**
     * 备注
     */
    public void setMemo(String memo) {
        this.memo = memo;
    }
    /**
     * 清单主键
     */
    public String getInfoId() {
        return infoId;
    }

    /**
     * 清单主键
     */
    public void setInfoId(String infoId) {
        this.infoId = infoId;
    }
    /**
     * 清单编码
     */
    public String getInfoCode() {
        return infoCode;
    }

    /**
     * 清单编码
     */
    public void setInfoCode(String infoCode) {
        this.infoCode = infoCode;
    }
    /**
     * 清单名称
     */
    public String getInfoName() {
        return infoName;
    }

    /**
     * 清单名称
     */
    public void setInfoName(String infoName) {
        this.infoName = infoName;
    }
    /**
     * 单位
     */
    public String getUnit() {
        return unit;
    }

    /**
     * 单位
     */
    public void setUnit(String unit) {
        this.unit = unit;
    }
    /**
     * 数量
     */
    public java.math.BigDecimal getNum() {
        return num;
    }

    /**
     * 数量
     */
    public void setNum(java.math.BigDecimal num) {
        this.num = num;
    }
    /**
     * 无税单价
     */
    public java.math.BigDecimal getPrice() {
        return price;
    }

    /**
     * 无税单价
     */
    public void setPrice(java.math.BigDecimal price) {
        this.price = price;
    }
    /**
     * 金额
     */
    public java.math.BigDecimal getMny() {
        return mny;
    }

    /**
     * 金额
     */
    public void setMny(java.math.BigDecimal mny) {
        this.mny = mny;
    }
    
}

==> cscec5b-fbxt-api-3.0.1-20211203.042743-20-sources.jar: com/ejianc/business/fbxt/grap/vo/GrapDetailVO.java <==
package com.ejianc.business.fbxt.grap.vo;

import java.math.BigDecimal;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;
import com.ejianc.framework.skeleton.template.BaseVO;


/**
 * 进度计量子表实体
 * 
 * @author generator
 * 
 */
public class GrapDetailVO extends BaseVO {
    private static final long serialVersionUID = 1L;
    
    private Long grapId; // 主表主键ID
    private String memo; // 备注
    private String infoId; // 清单主键
    private String infoCode; // 清单编码
    private String infoName; // 清单名称
    private String unit; // 单位
    private java.math.BigDecimal num; // 数量
    private java.math.BigDecimal price; // 无税单价
    private java.math.BigDecimal mny; // 金额
    private java.math.BigDecimal pcaAmout; // 供方完成量
    private String site; // 施工部位
    private java.math.BigDecimal amout;//审核数量

    public BigDecimal getPcaAmout() {
        return pcaAmout;
    }

    public void setPcaAmout(BigDecimal pcaAmout) {
        this.pcaAmout = pcaAmout;
    }

    public BigDecimal getAmout() {
        return amout;
    }

    public void setAmout(BigDecimal amout) {
        this.amout = amout;
    }

    public String getSite() {
        return site;
    }

    public void setSite(String site) {
        this.site = site;
    }


    /**
     * 主表主键ID
     */
    public Long getGrapId() {
        return grapId;
    }

    /**
     * 主表主键ID
     */
    public void setGrapId(Long grapId) {
        this.grapId = grapId;
    }
    /**
     * 备注
     */
    public String getMemo() {
        return memo;
    }

    /**
     * 备注
     */
    public void setMemo(String memo) {
        this.memo = memo;
    }
    /**
     * 清单主键
     */
    public String getInfoId() {
        return infoId;
    }

    /**
     * 清单主键
     */
    public void setInfoId(String infoId) {
        this.infoId = infoId;
    }
    /**
     * 清单编码
     */
    public String getInfoCode() {
        return infoCode;
    }

    /**
     * 清单编码
     */
    public void setInfoCode(String infoCode) {
        this.infoCode = infoCode;
    }
    /**
     * 清单名称
     */
    public String getInfoName() {
        return infoName;
    }

    /**
     * 清单名称
     */
    public void setInfoName(String infoName) {
        this.infoName = infoName;
    }
    /**
     * 单位
     */
    public String getUnit() {
        return unit;
    }

    /**
     * 单位
     */
    public void setUnit(String unit) {
        this.unit = unit;
    }
    /**
     * 数量
     */
    public java.math.BigDecimal getNum() {
        return num;
    }

    /**
     * 数量
     */
    public void setNum(java.math.BigDecimal num) {
        this.num = num;
    }
    /**
     * 无税单价
     */
    public java.math.BigDecimal getPrice() {
        return price;
    }

    /**
     * 无税单价
     */
    public void setPrice(java.math.BigDecimal price) {
        this.price = price;
    }
    /**
     * 金额
     */
    public java.math.BigDecimal getMny() {
        return mny;
    }

    /**
     * 金额
     */
    public void setMny(java.math.BigDecimal mny) {
        this.mny = mny;
    }
    
}
